<?php
/************************************************************************\
 *
 * VaultWiki
 * Version CES_VERSION
 * License #LICENSE_NUMBER
 *
 * CES_VAULT_COPYRIGHT
 *
\************************************************************************/

if (!defined('CES_UNINSTALL') OR CES_UNINSTALL != 1)
{
	exit("This file cannot be called directly.");
}

if (!defined('VAULT_40X_COMPAT'))
{
	if (substr(SIMPLE_VERSION, 0, 1) < 4)
	{
		define('VAULT_40X_COMPAT', 0);
	}
	else
	{
		define('VAULT_40X_COMPAT', 1);
	}
}

function vw_drop_table($table)
{
	global $db, $uninstall_phrases;

	echo sprintf($uninstall_phrases['drop_table'], TABLE_PREFIX . $table);
	vbflush();

	$db->query_write("
		DROP TABLE IF EXISTS " . TABLE_PREFIX . "$table
	");
}

function vw_delete_from($table, $where)
{
	global $db, $uninstall_phrases;

	echo sprintf($uninstall_phrases['deleting_entries'], TABLE_PREFIX . $table);
	vbflush();

	$db->query_write("
		DELETE FROM " . TABLE_PREFIX . "$table
		WHERE $where
	");
}

// vault/tools/uninstall_language_en.php
$GLOBALS['uninstall_phrases'] = array(
	'create_table' => 'Creating %1$s table',
	'drop_table' => 'Removing %1$s table',
	'alter_table' => 'Altering %1$s table',
	'update_table' => 'Updating %1$s table',
	'deleting_entries' => 'Removing entries from %1$s table',

	'rebuilding_bitfields' => 'Rebuilding Bitfields',
	'rebuilding_forum_info' => 'Rebuilding Forum Information',
	'rebuilding_bbcode_cache' => 'Rebuilding BB-Code Cache',
	'rebuilding_contenttype_cache' => 'Rebuilding Content Type Cache'
);

echo '<ul> ';
vbflush();

require_once(DIR . '/includes/class_dbalter.php');
$db_alter = new vB_Database_Alter_MySQL($db);

$bbcodes = array(
	'redirect'
);

if ($db_alter->fetch_table_info('vault_namespace'))
{
	// don't use cache, maybe never built
	$namespaces = $db->query_read("
		SELECT bbcodetag
		FROM " . TABLE_PREFIX . "vault_namespace
	");

	while ($nsinfo = $db->fetch_array($namespaces))
	{
		$bbcodes[$nsinfo['bbcodetag']] = $nsinfo['bbcodetag'];
	}
	$db->free_result($namespaces);
	unset($nsinfo);
}

if ($db_alter->fetch_table_info('bbcode'))
{
	$vw4_bbcodes = $db->query_read("
		SELECT *
		FROM " . TABLE_PREFIX . "bbcode
		WHERE bbcodetag IN ('" . implode("', '", $bbcodes) . "')
	");

	while ($bbcode = $db->fetch_array($vw4_bbcodes))
	{
		if (
			!empty($bbcode['vw_varname']) AND
			preg_match('#^vwp?_#', $bbcode['vw_varname'], $m)
		)
		{
			unset($bbcodes[$bbcode['bbcodetag']]);
		}
	}
	$db->free_result($vw4_bbcodes);
	unset($bbcode);
}

if ($bbcodes)
{
	vw_delete_from('bbcode', "bbcodetag IN ('" . implode("', '", $bbcodes) . "')");
}

vw_delete_from('adminmessage', "varname LIKE 'vault_changes_%'");

if (VAULT_40X_COMPAT)
{
	vw_delete_from('package', "productid = 'ces_nwsp_spec'");
	vw_delete_from('contenttype', "class = 'VaultArticle'");
}

vw_delete_from('phrasetype', "fieldname IN
(
	'vaultarticles',
	'specialpages',
	'vaultadmin',
	'vaultstyle',
	'vaultbbcode',
	'vaultprotect',
	'vaultnamespace',
	'vaultdomain',
	'vaultfaq',
	'vaulturl',

	/* legacy fields */
	'nuwikiarticles'
)");

/* legacy rows */
vw_delete_from('datastore', "title = 'vaultlist'");

// #############################################################################

vw_drop_table("vault_domain");
vw_drop_table("vault_revision");
vw_drop_table("vault_article");
vw_drop_table("vault_book");
vw_drop_table("vault_extension");
vw_drop_table("vault_link");
vw_drop_table("vault_namespace");
vw_drop_table("vault_namespacesort");
vw_drop_table("vault_protect");
vw_drop_table("vault_forummap");
vw_drop_table("vault_list");
// ############# START PREMIUM CODE FRAGMENT #############
vw_drop_table("vault_category");
vw_drop_table("vault_group");
vw_drop_table("vault_language");
// ############## END PREMIUM CODE FRAGMENT ##############
vw_drop_table("vault_upgradelog");
vw_drop_table("vault_header");
vw_drop_table("vault_log");
vw_drop_table("vault_options");
vw_drop_table("vault_chapter");

/* legacy tables */
vw_drop_table("nuwiki_ceslinktext");
vw_drop_table("nuwiki_ceslink");
vw_drop_table("nuwiki_extension");

// #############################################################################

if ($db_alter->fetch_table_info('session'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'session') . '</li> ';
	vbflush();

	if (!$vbulletin->options['bbactive'])
	{
		$db->query_write("
			DELETE FROM " . TABLE_PREFIX . "session
			WHERE userid != " . intval($vbulletin->userinfo['userid']) . "
		");
	}

	$db_alter->drop_field(array(
		'inwiki'
	));
}

if ($db_alter->fetch_table_info('thread'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'thread') . '</li> ';
	vbflush();

	$db_alter->drop_index(array(
		'firstpostid'
	));

	$db_alter->drop_field(array(
		'vault_description',

		/* legacy fields */
		'nuwiki_parent',
		'namespaceid'
	));
}

if ($db_alter->fetch_table_info('usergroup'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'usergroup') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'specialpage_permissions',
// ############# START PREMIUM CODE FRAGMENT #############
		'vault_misc',
// ############## END PREMIUM CODE FRAGMENT ##############
		'vault_permissions'
	));
}

if ($db_alter->fetch_table_info('style'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'style') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'wiki_css'
	));
}

if ($db_alter->fetch_table_info('language'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'language') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'phrasegroup_vaultarticles',
		'phrasegroup_specialpages',
		'phrasegroup_vaultadmin',
		'phrasegroup_vaultstyle',
		'phrasegroup_vaultbbcode',
		'phrasegroup_vaultprotect',
		'phrasegroup_vaultnamespace',
		'phrasegroup_vaultdomain',
		'phrasegroup_vaultfaq',
		'phrasegroup_vaulturl',

		/* legacy fields */
		'phrasegroup_nuwikiarticles'
	));
}

if ($db_alter->fetch_table_info('forumpermission'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'forumpermission') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'vault_permissions'
	));
}

if ($db_alter->fetch_table_info('poll'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'poll') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'position'
	));
}

if ($db_alter->fetch_table_info('forum'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'forum') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'vault_type',
		'vault_options',
		'vault_lastthread',
		'vault_lastedit',

		/* legacy fields */
		'vault_displayparent',
		'vault_displayname'
	));
}

if ($db_alter->fetch_table_info('bbcode'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'bbcode') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'wikioptions'
	));
}

if ($db_alter->fetch_table_info('post'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'post') . '</li> ';
	vbflush();

	/* legacy fields */
	$db_alter->drop_field(array(
		'vault_options'
	));
}

if ($db_alter->fetch_table_info('user'))
{
	echo '<li>' . sprintf($GLOBALS['uninstall_phrases']['alter_table'], TABLE_PREFIX . 'user') . '</li> ';
	vbflush();

	$db_alter->drop_field(array(
		'vault_edits'
	));
}

// #############################################################################

// rebuild info
echo "<li>$uninstall_phrases[rebuilding_bitfields]</li>\n";
echo '<!-- ' . htmlspecialchars_uni($uninstall_phrases['rebuilding_bitfields']) . " -->\n\n";
vbflush();

require_once(DIR . '/includes/class_bitfield_builder.php');
vB_Bitfield_Builder::save($db);

echo "<li>$uninstall_phrases[rebuilding_forum_info]</li>\n";
echo '<!-- ' . htmlspecialchars_uni($uninstall_phrases['rebuilding_forum_info']) . " -->\n\n";
vbflush();

build_forum_permissions();

echo "<li>$uninstall_phrases[rebuilding_bbcode_cache]</li>\n";
echo '<!-- ' . htmlspecialchars_uni($uninstall_phrases['rebuilding_bbcode_cache']) . " -->\n\n";
vbflush();

build_bbcode_cache();

if (VAULT_40X_COMPAT)
{
	echo "<li>$uninstall_phrases[rebuilding_contenttype_cache]</li>\n";
	echo '<!-- ' . htmlspecialchars_uni($uninstall_phrases['rebuilding_contenttype_cache']) . " -->\n\n";
	vbflush();

	require_once(DIR . '/includes/class_bootstrap_framework.php');
	vB_Bootstrap_Framework::init();
	vB_Cache::instance()->purge('vb_types.types');
	vB_Shutdown::instance()->shutdown();
}

echo '</ul>';
vbflush();

/* License Box */